#
# spec file for package mpv
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Jiri Slaby <jslaby@suse.de>
# Copyright (c) 2011-2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           mpv
Version:        0.2.3
Release:        3.2
License:        GPL-2.0+
Summary:        Advanced General Purpose Video Player
Url:            http://mpv.io/
Group:          Productivity/Multimedia/Video/Players
Source:         http://github.com/mpv-player/%{name}/archive/v%{version}.tar.gz
BuildRequires:  hicolor-icon-theme
BuildRequires:  ladspa-devel
BuildRequires:  libffmpeg-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmng-devel
BuildRequires:  libmpg123-devel
BuildRequires:  linux-kernel-headers
BuildRequires:  lirc-devel
BuildRequires:  lua-devel
BuildRequires:  ncurses-devel
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  pulseaudio-devel
BuildRequires:  python3
BuildRequires:  yasm
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(caca)
BuildRequires:  pkgconfig(cucul)
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(dvdread)
BuildRequires:  pkgconfig(enca)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libbluray)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libiso9660)
BuildRequires:  pkgconfig(libudf)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(smbclient)
BuildRequires:  pkgconfig(vdpau)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Pdf manual
# JIT for lua
%if 0%{?suse_version} > 01310
BuildRequires:  luajit-devel
BuildRequires:  python-rst2pdf
BuildRequires:  tex(cmap.sty)
BuildRequires:  tex(fixltx2e.sty)
BuildRequires:  tex(fullpage.sty)
BuildRequires:  tex(ltcaption.sty)
BuildRequires:  texlive-latex
%endif
# wayland and libguess
%if 0%{?suse_version} > 01230
BuildRequires:  pkgconfig(libguess)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(xkbcommon)
%endif
# libbs2b was not around before 12.2
# cdio was split to cdio-paranoia on older we are fine with just cdio-devel
%if 0%{?suse_version} > 01210
BuildRequires:  pkgconfig(libbs2b)
BuildRequires:  pkgconfig(libcdio_cdda)
BuildRequires:  pkgconfig(libcdio_paranoia)
%endif
# docutils were renamed to python-docutils
# libquvi was introduced with 12.1
# jack api changed and the old version is not supported
%if 0%{?suse_version} > 01140
# replace with python3-docutils when they are fixed
BuildRequires:  python-docutils
BuildRequires:  libquvi-devel
BuildRequires:  pkgconfig(jack)
%else
BuildRequires:  docutils
%endif

%description
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety of video
file formats, audio and video codecs, and subtitle types.

%prep
%setup -q

%build
# SDL: disable as it is pointless to have on linux, it is windows/mac fallback
myopts=" --disable-sdl --disable-sdl2"
# We don't want to rebuild all the time
myopts+=" --disable-build-date"
# Debug just adds -g and we do that over optflags anyway
myopts+=" --disable-debug"
# jack must be hard-disabled as it is still pulled in as dep
# libcdio on 12.2 is disaster, and it won't be fixed

# Drop me with 0.3 release where this is fixed:
CFLAGS="%{optflags} `pkg-config --cflags smbclient`" \
./configure \
    --prefix="%{_prefix}" \
    --bindir="%{_bindir}" \
    --mandir="%{_mandir}" \
    --docdir="%{_docdir}/%{name}" \
    --confdir="%{_sysconfdir}/%{name}" \
    --extra-cflags="%{optflags}" \
    --enable-openal \
%if 0%{?suse_version} < 01210
    --disable-jack \
%endif
%if 0%{?suse_version} == 01220
    --disable-libcdio \
%endif
    ${myopts}

make %{?_smp_mflags} V=1

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

%files
%defattr(-,root,root)
%doc LICENSE Copyright README.md etc/example.conf etc/encoding-example-profiles.conf etc/input.conf
%{_bindir}/%{name}
%doc %{_mandir}/man1/%{name}.1*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%changelog
* Sat Nov 23 2013 scarabeus@opensuse.org
- Reduce pkgconfig deps where it seems proper.
* Sat Nov 23 2013 scarabeus@opensuse.org
- Fix docu generating and add luajit dependency.
- Try to convert the deps to pkgconfig syntax.
* Sat Nov  9 2013 scarabeus@opensuse.org
- Verison bump to 0.2.3:
  * Handle more signals
  * Fix audio detection with some formats
  * More tiny fixes
* Wed Nov  6 2013 scarabeus@opensuse.org
- Version bump to 0.2.2:
  * Tiny bugfixes
- Depend on rst2tex when available, still broken configure check
  to be fixed next time.
* Mon Oct 21 2013 scarabeus@opensuse.org
- Version bump to 0.2.1:
  * Various small fixes
- Fix build with samba again, fixed in git properly for next
  release.
* Thu Oct 17 2013 scarabeus@opensuse.org
- Fix directory ownership on icondirs.
* Thu Oct 17 2013 scarabeus@opensuse.org
- Version bump to 0.2.0:
  * new icon
  * Add an On Screen Controller (OSC)
  * Subtitles: make automatic charset detection the default
  * More intuitive chapter seeking behavior
  * support for VA-API hardware decoding and display
  * Preliminary Lua scripting support
  * Switch to GPL version 2 or later for mpv as a whole
* Tue Sep 24 2013 scarabeus@opensuse.org
- Install configuration examples for users to inspire themselves.
* Mon Sep 23 2013 scarabeus@opensuse.org
- Version bump to 0.1.7:
  * manpage fixes
  * mkv subtitle fixes
  * various bugfixes
* Mon Sep 16 2013 scarabeus@opensuse.org
- Make mpv build on 12.2 too, what a release.
* Mon Sep 16 2013 scarabeus@opensuse.org
- Disable jack on 11.4 so the package actually builds.
* Mon Sep 16 2013 scarabeus@opensuse.org
- And make 11.4 happy too wrt dep resolution.
* Mon Sep 16 2013 scarabeus@opensuse.org
- Make this work with older releases too (versioned ifs for deps).
* Sun Sep 15 2013 scarabeus@opensuse.org
- Update license and ship readme.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Fix description.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Fix dep on python3-docutils as they are borked now, use py2 for
  time being, told sachpe to figure it out.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Sort out remaining dependencies so we can build.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Initial spec file for mpv media player.
  * Based from mplayer2 spec.
